@@ -177,7 +177,7 @@ class RNADiffAnalysis:
         self.design = RNADesign(design_file, sep=sep_design, reference=reference)
         self.comparisons = comparisons if comparisons else self.design.comparisons
 
-    
+
         _conditions = {x for comp in self.comparisons for x in comp}
         if not keep_all_conditions:
             self.design.keep_conditions(_conditions)
@@ -273,7 +273,12 @@ Design overview:\n\
         except ValueError:
             counts = FeatureCount(self.usr_counts).df
 
+        if self.minimum_mean_reads_per_gene > 0:
+            logger.info(f"{len(counts)} annotated feature to be processed")
         counts = counts[counts.mean(axis=1) > self.minimum_mean_reads_per_gene]
+        if self.minimum_mean_reads_per_gene > 0:
+            logger.info(f"Keeping {len(counts)} features after removing low "
+                f"counts below {self.minimum_mean_reads_per_gene} on average")
 
         # filter count based on the design and the comparisons provide in the
         # constructor so that columns match as expected by a DESeq2 analysis.
@@ -1063,14 +1068,14 @@ class RNADiffResults:
         df["group_color"] = df.loc[:, condition].map(col_map)
         return df
 
-    def _format_plot(self, title="", xlabel="", ylabel="", rotation=0):
+    def _format_plot(self, title="", xlabel="", ylabel="", rotation=0, fontsize=None):
         pylab.title(title)
-        pylab.xticks(rotation=rotation, ha="right")
+        pylab.xticks(rotation=rotation, ha="right", fontsize=fontsize)
         pylab.xlabel(xlabel)
         pylab.ylabel(ylabel)
 
     def get_specific_commons(self, direction, compas=None, annot_col="index"):
-        """Extract gene lists for all comparisons. 
+        """Extract gene lists for all comparisons.
 
         Genes are common (but specific, ie a gene appear only appears in the
         combination considered) comparing all combinations of comparisons.
@@ -1159,7 +1164,7 @@ class RNADiffResults:
         except:
             pass
 
-    def plot_percentage_null_read_counts(self):
+    def plot_percentage_null_read_counts(self, fontsize=None, xticks_fontsize=None):
         """Bars represent the percentage of null counts in each samples.  The dashed
         horizontal line represents the percentage of feature counts being equal
         to zero across all samples
@@ -1175,6 +1180,10 @@ class RNADiffResults:
 
         """
         self._set_figsize()
+        if fontsize is None:
+            fontsize = self.fontsize
+        if xticks_fontsize is None:
+            xticks_fontsize = self.xticks_fontsize
 
         # how many null counts ?
         df = (self.counts_raw == 0).sum() / self.counts_raw.shape[0] * 100
@@ -1189,7 +1198,7 @@ class RNADiffResults:
 
         pylab.axhline(all_null, ls="--", color="black", alpha=0.5)
 
-        pylab.xticks(rotation=45, ha="right")
+        pylab.xticks(rotation=45, ha="right", fontsize=xticks_fontsize)
         pylab.ylabel("Proportion of null counts (%)")
         pylab.grid(True, zorder=0)
         pylab.tight_layout()
@@ -1201,6 +1210,7 @@ class RNADiffResults:
         plotly=False,
         max_features=500,
         genes_to_remove=[],
+        fontsize=10
     ):
 
         """
@@ -1223,7 +1233,6 @@ class RNADiffResults:
             r.plot_pca(colors=colors)
         """
         from sequana.viz import PCA
-
         # Get most variable genes (n=max_features)
         top_features = (
             self.counts_vst.var(axis=1)
@@ -1289,6 +1298,7 @@ class RNADiffResults:
                 n_components=n_components,
                 colors=self.design_df.group_color,
                 max_features=max_features,
+                fontsize=fontsize
             )
 
         return variance
@@ -1330,8 +1340,12 @@ class RNADiffResults:
             ylabel="Density",
         )
 
-    def plot_feature_most_present(self):
+    def plot_feature_most_present(self, fontsize=None, xticks_fontsize=None):
         """"""
+        if fontsize is None:
+            fontsize = self.fontsize
+        if xticks_fontsize is None:
+            xticks_fontsize = self.xticks_fontsize
 
         df = []
 
@@ -1363,6 +1377,7 @@ class RNADiffResults:
             ec="k",
             height=0.9,
         )
+        pylab.yticks(fontsize=xticks_fontsize)
 
         for idx, rect in enumerate(p):
             pylab.text(
@@ -1373,12 +1388,14 @@ class RNADiffResults:
                 va="center",
                 rotation=0,
                 zorder=20,
+                fontsize=xticks_fontsize
             )
 
         self._format_plot(
             # title="Counts monopolized by the most expressed gene",
             # xlabel="Sample",
             xlabel="Percent of total reads",
+            fontsize=xticks_fontsize
         )
         pylab.tight_layout()
 
@@ -1424,8 +1441,14 @@ class RNADiffResults:
         d.category = self.design_df[self.condition].map(group_conv).to_dict()
         d.plot()
 
-    def plot_boxplot_rawdata(self, fliersize=2, linewidth=2, rotation=0, **kwargs):
+    def plot_boxplot_rawdata(self, fliersize=2, linewidth=2, rotation=0,
+            fontsize=None, xticks_fontsize=None, **kwargs):
+
         import seaborn as sbn
+        if fontsize is None:
+            fontsize = self.fontsize
+        if xticks_fontsize is None:
+            xticks_fontsize = self.xticks_fontsize
 
         ax = sbn.boxplot(
             data=self.counts_raw.clip(1),
@@ -1438,11 +1461,17 @@ class RNADiffResults:
         pylab.xticks(pos, labs, rotation=rotation)
         ax.set_ylabel("Counts (raw) in log10 scale")
         ax.set_yscale("log")
-        self._format_plot(ylabel="Raw count distribution")
+        self._format_plot(ylabel="Raw count distribution", fontsize=xticks_fontsize)
         pylab.tight_layout()
 
-    def plot_boxplot_normeddata(self, fliersize=2, linewidth=2, rotation=0, **kwargs):
+    def plot_boxplot_normeddata(self, fliersize=2, linewidth=2, rotation=0,
+        fontsize=None, xticks_fontsize=None, **kwargs):
+
         import seaborn as sbn
+        if fontsize is None:
+            fontsize = self.fontsize
+        if xticks_fontsize is None:
+            xticks_fontsize = self.xticks_fontsize
 
         ax = sbn.boxplot(
             data=self.counts_norm.clip(1),
