@@ -35,8 +35,9 @@ from easydev import precision
 from easydev.misc import cmd_exists
 import subprocess
 
-from sequana import logger
-logger.name = __name__
+import colorlog
+logger = colorlog.getLogger(__name__)
+
 
 
 __all__ = ['StatsBAM2Mapped', 'bam_to_mapped_unmapped_fastq', "GZLineCounter"]
